slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDTRLanczosSetScale

Sets the scale parameter for the GSVD.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDTRLanczosSetScale(SVD svd,PetscReal scale)

Logically Collective on svd

### Input Parameters

| svd | - singular value solver
| scale | - scale parameter

### Options Database Key

| -svd_trlanczos_scale <real> | - scale factor/threshold

### Notes

This parameter is relevant for the GSVD case only. If the parameter is positive, it indicates the scale factor for B in matrix Z=[A;B]. If negative, its absolute value is the threshold for automatic scaling. In automatic scaling, whenever the largest approximate generalized singular value (or the inverse of the smallest value, if SVD_SMALLEST is used) exceeds the threshold, the computation is restarted with matrix B scaled by that value.

### See Also

SVDTRLanczosGetScale()

### Level

advanced

### Location

src/svd/impls/trlanczos/trlanczos.c

### Examples

src/svd/tutorials/ex51.c.html
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages